@@ -1,11 +1,11 @@
 package Evo::XS;
-use Evo;
-use XSLoader;
-XSLoader::load("Evo::XS", '0.005');
+use Evo 'Evo::Class::Attrs::XS';
+
+our $VERSION = '0.006';    # VERSION
 
 1;
 
-# ABSTRACT: Evo::XS - Evo parts written in C for performance
+# ABSTRACT: Evo parts written in C
 
 __END__
 
@@ -15,11 +15,11 @@ __END__
 
 =head1 NAME
 
-Evo::XS - Evo::XS - Evo parts written in C for performance 
+Evo::XS - Evo parts written in C
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 AUTHOR
 
